@@ -7,14 +7,14 @@ use Data::Range::Compare::Stream::Constants qw(RANGE_START RANGE_END RANGE_DATA)
 
 use constant NEW_FROM_CLASS=>'Data::Range::Compare::Stream';
 
-our $VERSION='2.014';
+our $VERSION='2.015';
 
 sub new {
   my ($class,@args)=@_;
   bless [@args],$class;
 }
 
-sub to_string () {
+sub to_string {
   my $notation=join ' - ',$_[0]->range_start_to_string,$_[0]->range_end_to_string;
   $notation;
 }
